# -*- coding:utf-8 -*-

from unittest import TestCase

from cpf_cnpj import Cpf, Cnpj

class CnpjTest(TestCase):

    def setUp(self):
        self.cnpj_valid_with_formatting = Cnpj('65.025.861/0001-70')
        self.cnpj_valid_without_formatting = Cnpj('65025861000170')
        self.cnpj_invalid_with_formatting = Cnpj('61.882.613/0001-95')
        self.cnpj_invalid_without_formatting = Cnpj('61882613000195')
        self.cnpj_invalid_amount_with_formatting = Cnpj('61.882.613/0001-9')
        self.cnpj_invalid_amount_without_formatting = Cnpj('6188261300019')

    def test_calculating_first_digit(self):
        self.assertEqual(
            self.cnpj_valid_without_formatting.calculating_first_digit(), '7')

    def test_calculating_second_digit(self):
        self.assertEqual(
            self.cnpj_valid_without_formatting.calculating_second_digit(), '0')

    def test_cnpj_valid_without_formatting(self):
        self.assertTrue(self.cnpj_valid_without_formatting.validate())

    def test_cnpj_valid_with_formatting(self):
        self.assertTrue(self.cnpj_valid_with_formatting.validate())

    def test_cnpj_invalid_without_formatting(self):
        self.assertFalse(self.cnpj_invalid_without_formatting.validate())

    def test_cnpj_invalid_with_formatting(self):
        self.assertFalse(self.cnpj_invalid_with_formatting.validate())

    def test_cnpj_invalid_amount_without_formatting(self):
        self.assertFalse(self.cnpj_invalid_amount_without_formatting.validate())

    def test_cnpj_invalid_amount_with_formatting(self):
        self.assertFalse(self.cnpj_invalid_amount_with_formatting.validate())

    def test_cnpj_valid_format(self):
        self.assertEqual(self.cnpj_valid_without_formatting.format(),
            '65.025.861/0001-70')

    def test_cnpj_invalid_format(self):
        self.assertNotEqual(self.cnpj_valid_with_formatting.format(),
            '65025861000170')

class CpfTest(TestCase):

    def setUp(self):
        self.cpf_with_formatting = Cpf('010.787.400-89')
        self.cpf_without_formatting = Cpf('01078740089')

    def test_cpf_with_formatting_validate_suze_return_true(self):
        self.assertTrue(self.cpf_with_formatting.validate_size())

    def test_cpf_without_formatting_validate_suze_return_true(self):
        self.assertTrue(self.cpf_without_formatting.validate_size())

    def test_cpf_validate_size_return_false(self):
        cpf = Cpf('1234567891')
        self.assertFalse(cpf.validate_size())

    def test_cpf_format_return_true(self):
        self.assertEqual(self.cpf_without_formatting.format(), '010.787.400-89')

    def test_cpf_format_return_false(self):
        self.assertNotEqual(self.cpf_without_formatting.format(), '01078740089')

    def test_cpf_cleaning_return_true(self):
        self.assertEqual(self.cpf_with_formatting.cleaning(), '01078740089')

    def test_cpf_cleaning_return_false(self):
        self.assertNotEqual(self.cpf_with_formatting.cleaning(),
            '010787400-89')

    def test_cpf_with_formatting_validate_return_true(self):
        self.assertTrue(self.cpf_with_formatting.validate())

    def test_cpf_with_formatting_validate_return_false(self):
        cpf = Cpf('010.787.400-8')
        self.assertFalse(cpf.validate())

    def test_cpf_without_formatting_validate_return_false(self):
        cpf = Cpf('0107874008')
        self.assertFalse(cpf.validate())

    def test_cpf_without_formatting_validate_return_true(self):
        self.assertTrue(self.cpf_without_formatting.validate())


# -*- coding:utf-8 -*-

class Cnpj(object):

    def __init__(self, cnpj):
        """
        Class to interact with cnpj brazilian numbers
        """
        self.cnpj = cnpj

    def calculating_digit(self, result):
        result = result % 11
        if result < 2:
            digit = 0
        else:
            digit = 11 - result
        return str(digit)

    def calculating_first_digit(self):
        one_validation_list = [5, 4, 3, 2, 9, 8, 7, 6, 5, 4 , 3, 2]
        result = 0
        pos = 0
        for number in self.cnpj:
            try:
                one_validation_list[pos]
            except IndexError:
                break
            result += int(number) * int(one_validation_list[pos])
            pos += 1
        return self.calculating_digit(result)

    def calculating_second_digit(self):
        two_validation_list = [6, 5, 4, 3, 2, 9, 8, 7, 6, 5, 4, 3, 2]
        result = 0
        pos = 0
        for number in self.cnpj:
            try:
                two_validation_list[pos]
            except IndexError:
                break
            result += int(number) * int(two_validation_list[pos])
            pos += 1
        return self.calculating_digit(result)

    def validate(self):
        """
        Method to validate brazilian cnpjs
        """
        self.cnpj = self.cleaning()

        if len(self.cnpj) != 14:
            return False

        checkers = self.cnpj[-2:]

        digit_one = self.calculating_first_digit()
        digit_two = self.calculating_second_digit()

        return bool(checkers == digit_one + digit_two)

    def cleaning(self):
        return self.cnpj.replace('-', '').replace('.', '').replace('/', '')

    def format(self):
        """
        Method to format cnpj numbers.
        """
        return '%s.%s.%s/%s-%s' % (self.cnpj[0:2], self.cnpj[2:5],
            self.cnpj[5:8], self.cnpj[8:12], self.cnpj[12:14])

class Cpf(object):

    def __init__(self, cpf):
        self.cpf = cpf

    def validate_size(self):
        cpf = self.cleaning()
        if len(cpf) > 11 or len(cpf) < 11:
            return False
        return True

    def validate(self):
        if self.validate_size():
            digit_1 = 0
            digit_2 = 0
            i = 0
            cpf = self.cleaning()
            while i < 10:
                digit_1 = ((digit_1 + (int(cpf[i]) * (11-i-1))) % 11
                    if i < 9 else digit_1)
                digit_2 = (digit_2 + (int(cpf[i]) * (11-i))) % 11
                i += 1
            return ((int(cpf[9]) == (11 - digit_1 if digit_1 > 1 else 0)) and
                    (int(cpf[10]) == (11 - digit_2 if digit_2 > 1 else 0)))
        return False

    def cleaning(self):
        return self.cpf.replace('.', '').replace('-', '')

    def format(self):
        return '%s.%s.%s-%s' % (
            self.cpf[0:3], self.cpf[3:6], self.cpf[6:9], self.cpf[9:11])


# -*- coding:utf-8 -*-

import os
from setuptools import setup, find_packages

def parse_requirements(requirements):
    with open(requirements) as f:
        return [l.strip('\n') for l in f if l.strip('\n') and not l.startswith('#')]

required = parse_requirements('requirements.txt')

setup(
    install_requires=required,
    name = "cpf_cnpj",
    version = '0.1.2',
    description = "Validador de CPF e CNPJ para Python",
    license = "MIT",
    author = "Adriano Margarin",
    author_email = "adriano.margarin@gmail.com",
    url = "https://github.com/amargarin/cpf_cnpj",
    packages = find_packages(exclude = ['tests']),
    keywords = "python cpf cnpj validador",
    zip_safe = True
)
